@@ -1,12 +1,12 @@
 # Scheme: [N!]N(.N)*[{a|b|rc}N][.postN][.devN]
-__version__ = '0.36.1'
+__version__ = '0.38.1'
 
 from ._parameter import Parameter
 from ._argument import Argument
 from ._externallink import ExternalLink
 from ._wikilink import WikiLink
 from ._section import Section
-from ._comment import Comment
+from ._comment_bold_italic import Comment, Bold, Italic
 from . import _wikitext
 from ._table import Table
 from ._template import Template
@@ -20,6 +20,8 @@ _wikitext.ExternalLink = ExternalLink
 _wikitext.WikiLink = WikiLink
 _wikitext.Template = Template
 _wikitext.Comment = Comment
+_wikitext.Bold = Bold
+_wikitext.Italic = Italic
 _wikitext.ParserFunction = ParserFunction
 _wikitext.Parameter = Parameter
 _wikitext.Table = Table
@@ -30,3 +32,4 @@ _wikitext.Tag = _wikitext.ExtensionTag = Tag
 
 WikiText = _wikitext.WikiText
 parse = WikiText
+remove_markup = _wikitext.remove_markup
