@@ -52,9 +52,11 @@ T = TypeVar('T')
 
 class Table(SubWikiTextWithAttrs):
 
-    """Create a new Table object."""
+    __slots__ = '_attrs_match_cache'
 
-    _attrs_match_cache = None, None
+    def __init__(self, *args, **kwargs):
+        super().__init__(*args, **kwargs)
+        self._attrs_match_cache = None, None
 
     @property
     def nesting_level(self) -> int:
@@ -69,8 +71,8 @@ class Table(SubWikiTextWithAttrs):
     def _table_shadow(self) -> bytearray:
         """Remove Table spans from shadow and return it."""
         shadow = self._shadow[:]
-        ss = self._span[0]
-        for s, e in self._subspans('Table'):
+        ss = self._span_data[0]
+        for s, e, _, _ in self._subspans('Table'):
             if s == ss:
                 continue
             shadow[s - ss:e - ss] = b'#' * (e - s)
@@ -199,7 +201,7 @@ class Table(SubWikiTextWithAttrs):
         If only need the values inside cells, then use the ``data`` method
         instead.
         """
-        tbl_span = self._span
+        tbl_span = self._span_data
         ss = tbl_span[0]
         match_table = self._match_table
         shadow = self._shadow
@@ -219,7 +221,7 @@ class Table(SubWikiTextWithAttrs):
                 row_attrs_append = row_attrs.append
             for m in match_row:
                 ms, me = m.span()
-                cell_span = [ss + ms, ss + me]
+                cell_span = [ss + ms, ss + me, None, shadow[ms:me]]
                 if span:
                     s, e = m.span('attrs')
                     # Note: ATTRS_MATCH always matches, even to empty strings.
@@ -439,7 +441,7 @@ def _apply_attr_spans(
 def _lstrip_increase(shadow: bytearray, pos: int) -> int:
     """Return the new position to lstrip the shadow."""
     length = len(shadow)
-    while pos < length and shadow[pos:pos + 1].isspace():
+    while pos < length and shadow[pos] in {0, 9, 10, 32}:  # \0 \t \n space
         pos += 1
     return pos
 
